@@ -77,7 +77,7 @@ public:
 
       //Cache object is created the first time this runs.
       //It will live throughout the lifetime of the application
-      KeyCache::self()->addKeys(path);
+      KeyCache::self()->addKeys( path );
     }
 
     Private( const Private& rhs )
@@ -97,57 +97,53 @@ public:
     QStringList subPaths() const
     {
         QStringList paths;
-        paths << path + QString::fromLatin1("/cur");
-        paths << path + QString::fromLatin1("/new");
-        paths << path + QString::fromLatin1("/tmp");
+        paths << path + QString::fromLatin1( "/cur" );
+        paths << path + QString::fromLatin1( "/new" );
+        paths << path + QString::fromLatin1( "/tmp" );
         return paths;
     }
 
     QStringList listNew() const
     {
-        QDir d( path + QString::fromLatin1("/new") );
-        return d.entryList(QDir::Files);
+        QDir d( path + QString::fromLatin1( "/new" ) );
+        return d.entryList( QDir::Files );
     }
 
     QStringList listCurrent() const
     {
-        QDir d( path + QString::fromLatin1("/cur") );
-        return d.entryList(QDir::Files);
+        QDir d( path + QString::fromLatin1( "/cur" ) );
+        return d.entryList( QDir::Files );
     }
 
     QString findRealKey( const QString& key ) const
     {
         KeyCache* keyCache = KeyCache::self();
-        if ( keyCache->isNewKey(path, key) ) {
+        if ( keyCache->isNewKey( path, key ) ) {
 #ifdef DEBUG_KEYCACHE_CONSITENCY
-          if (!QFile::exists(path + QString::fromLatin1("/new/") + key) )
-          {
-            kDebug() << "WARNING: key is in cache, but the file is gone: " << path + QString::fromLatin1("/new/") + key;
+          if ( !QFile::exists( path + QString::fromLatin1( "/new/" ) + key ) ) {
+            kDebug() << "WARNING: key is in cache, but the file is gone: " << path + QString::fromLatin1( "/new/" ) + key;
           }
 #endif
-          return path + QString::fromLatin1("/new/") + key;
+          return path + QString::fromLatin1( "/new/" ) + key;
         }
-        if ( keyCache->isCurKey(path, key) ) {
+        if ( keyCache->isCurKey( path, key ) ) {
 #ifdef DEBUG_KEYCACHE_CONSITENCY
-          if (!QFile::exists(path + QString::fromLatin1("/cur/") + key) )
-          {
-            kDebug() << "WARNING: key is in cache, but the file is gone: " << path + QString::fromLatin1("/cur/") + key;
+          if ( !QFile::exists( path + QString::fromLatin1( "/cur/" ) + key ) ) {
+            kDebug() << "WARNING: key is in cache, but the file is gone: " << path + QString::fromLatin1( "/cur/" ) + key;
           }
 #endif
-          return path + QString::fromLatin1("/cur/") + key;
+          return path + QString::fromLatin1( "/cur/" ) + key;
         }
-        QString realKey = path + QString::fromLatin1("/new/") + key;
+        QString realKey = path + QString::fromLatin1( "/new/" ) + key;
 
         QFile f( realKey );
-        if ( f.exists() )
-        {
-          keyCache->addNewKey(path, key);
+        if ( f.exists() ) {
+          keyCache->addNewKey( path, key );
         } else  { //not in "new", search in "cur"
-          realKey = path + QString::fromLatin1("/cur/") + key;
+          realKey = path + QString::fromLatin1( "/cur/" ) + key;
           QFile f2( realKey );
-          if ( f2.exists() )
-          {
-            keyCache->addCurKey(path, key);
+          if ( f2.exists() ) {
+            keyCache->addCurKey( path, key );
           } else {
             realKey.clear(); //not in "cur" either
           }
@@ -158,7 +154,7 @@ public:
 
     static QString subDirNameForFolderName( const QString &folderName )
     {
-        return QString::fromLatin1(".%1.directory").arg( folderName );
+        return QString::fromLatin1( ".%1.directory" ).arg( folderName );
     }
 
     QString subDirPath() const
@@ -211,7 +207,7 @@ void Maildir::swap( const Maildir &rhs )
 
 
 Maildir::Maildir(const Maildir & rhs)
-  :d( new Private(*rhs.d) )
+  :d( new Private( *rhs.d ) )
 
 {
 }
@@ -219,7 +215,7 @@ Maildir::Maildir(const Maildir & rhs)
 Maildir& Maildir::operator= (const Maildir & rhs)
 {
     // copy and swap, exception safe, and handles assignment to self
-    Maildir temp(rhs);
+    Maildir temp( rhs );
     swap( temp );
     return *this;
 }
@@ -238,9 +234,9 @@ Maildir::~Maildir()
 
 bool Maildir::Private::canAccess( const QString& path ) const
 {
-    //return access(QFile::encodeName( path ), R_OK | W_OK | X_OK ) != 0;
+    //return access( QFile::encodeName( path ), R_OK | W_OK | X_OK ) != 0;
     // FIXME X_OK?
-    QFileInfo d(path);
+    QFileInfo d( path );
     return d.isReadable() && d.isWritable();
 }
 
@@ -249,15 +245,14 @@ bool Maildir::Private::accessIsPossible( QString& error ) const
     QStringList paths = subPaths();
     paths.prepend( path );
 
-    Q_FOREACH( const QString &p, paths )
-    {
-        if ( !QFile::exists(p) ) {
-            error = i18n("Error opening %1; this folder is missing.",p);
+    Q_FOREACH ( const QString &p, paths ) {
+        if ( !QFile::exists( p ) ) {
+            error = i18n( "Error opening %1; this folder is missing.", p );
             return false;
         }
         if ( !canAccess( p ) ) {
-            error = i18n("Error opening %1; either this is not a valid "
-                    "maildir folder, or you do not have sufficient access permissions." ,p);
+            error = i18n( "Error opening %1; either this is not a valid "
+                    "maildir folder, or you do not have sufficient access permissions." ,p );
             return false;
         }
     }
@@ -277,7 +272,7 @@ bool Maildir::isValid( QString &error ) const
           return true;
       }
     } else {
-      foreach ( const QString &sf, subFolderList() ) {
+      Q_FOREACH ( const QString &sf, subFolderList() ) {
         const Maildir subMd = Maildir( path() + QLatin1Char( '/' ) + sf );
         if ( !subMd.isValid( error ) )
           return false;
@@ -296,7 +291,7 @@ bool Maildir::create()
 {
     // FIXME: in a failure case, this will leave partially created dirs around
     // we should clean them up, but only if they didn't previously existed...
-    Q_FOREACH( const QString &p, d->subPaths() ) {
+    Q_FOREACH ( const QString &p, d->subPaths() ) {
         QDir dir( p );
         if ( !dir.exists( p ) ) {
             if ( !dir.mkpath( p ) )
@@ -326,7 +321,7 @@ QString Maildir::addSubFolder( const QString& path )
     QDir dir( d->path );
     if ( !d->isRoot ) {
         dir.cdUp();
-        if (!dir.exists( d->subDirPath() ) )
+        if ( !dir.exists( d->subDirPath() ) )
             dir.mkdir( d->subDirPath() );
         dir.cd( d->subDirPath() );
     }
@@ -375,7 +370,7 @@ Maildir Maildir::parent() const
     return Maildir();
   QDir dir( d->path );
   dir.cdUp();
-  if ( !dir.dirName().startsWith( '.' ) || !dir.dirName().endsWith( QLatin1String(".directory") ) )
+  if ( !dir.dirName().startsWith( '.' ) || !dir.dirName().endsWith( QLatin1String( ".directory" ) ) )
     return Maildir();
   const QString parentName = dir.dirName().mid( 1, dir.dirName().size() - 11 );
   dir.cdUp();
@@ -405,7 +400,7 @@ QStringList Maildir::listCurrent() const
 
 QString Maildir::findRealKey(const QString& key) const
 {
-    return d->findRealKey(key);
+    return d->findRealKey( key );
 }
 
 
@@ -434,7 +429,7 @@ QStringList Maildir::subFolderList() const
     // the root maildir has its subfolders directly beneath it
     if ( !d->isRoot ) {
         dir.cdUp();
-        if (!dir.exists( d->subDirPath() ) ) return QStringList();
+        if ( !dir.exists( d->subDirPath() ) ) return QStringList();
         dir.cd( d->subDirPath() );
     }
     dir.setFilter( QDir::Dirs | QDir::NoDotAndDotDot );
@@ -505,7 +500,7 @@ QByteArray Maildir::readEntryHeadersFromFile( const QString& file ) const
         qWarning() << "Maildir::readEntryHeaders unable to find: " << file;
         return result;
     }
-    f.map(0, qMin((qint64)8000, f.size() ) );
+    f.map( 0, qMin( (qint64)8000, f.size() ) );
     forever {
         QByteArray line = f.readLine();
         if ( line.trimmed().isEmpty() )
@@ -531,9 +526,9 @@ static QString createUniqueFileName()
 {
     qint64 time = QDateTime::currentMSecsSinceEpoch() / 1000;
     int r = qrand() % 1000;
-    QString identifier = QLatin1String("R") + QString::number(r);
+    QString identifier = QLatin1String( "R" ) + QString::number( r );
 
-    QString fileName = QString::number(time) + QLatin1String(".") + identifier + QLatin1String(".");
+    QString fileName = QString::number( time ) + QLatin1String( "." ) + identifier + QLatin1String( "." );
 
     return fileName;
 }
@@ -581,7 +576,7 @@ QString Maildir::addEntry( const QByteArray& data )
      *
      * For reference: http://trolltech.com/developer/task-tracker/index_html?method=entry&id=211215
      */
-    if (!f.rename( finalKey )) {
+    if ( !f.rename( finalKey ) ) {
         qWarning() << "Maildir: Failed to add entry: " << finalKey  << "! Error: " << f.errorString();
     }
     KeyCache *keyCache = KeyCache::self();
@@ -600,7 +595,7 @@ bool Maildir::removeEntry( const QString& key )
     }
     KeyCache *keyCache = KeyCache::self();
     keyCache->removeKey( d->path, key );
-    return QFile::remove(realKey);
+    return QFile::remove( realKey );
 }
 
 QString Maildir::changeEntryFlags(const QString& key, const Akonadi::Item::Flags& flags)
@@ -612,49 +607,49 @@ QString Maildir::changeEntryFlags(const QString& key, const Akonadi::Item::Flags
         return key;
     }
 
-    const QRegExp rx = *(statusSeparatorRx());
+    const QRegExp rx = *( statusSeparatorRx() );
     QString finalKey = key.left( key.indexOf( rx ) );
 
     QStringList mailDirFlags;
-    Q_FOREACH( Akonadi::Item::Flag flag, flags ) {
+    Q_FOREACH ( const Akonadi::Item::Flag flag, flags ) {
       if ( flag == Akonadi::MessageFlags::Forwarded )
-        mailDirFlags << QLatin1String("P");
+        mailDirFlags << QLatin1String( "P" );
       if ( flag == Akonadi::MessageFlags::Replied )
-        mailDirFlags << QLatin1String("R");
+        mailDirFlags << QLatin1String( "R" );
       if ( flag == Akonadi::MessageFlags::Seen )
-        mailDirFlags << QLatin1String("S");
+        mailDirFlags << QLatin1String( "S" );
       if ( flag == Akonadi::MessageFlags::Deleted )
-        mailDirFlags << QLatin1String("T");
+        mailDirFlags << QLatin1String( "T" );
       if ( flag == Akonadi::MessageFlags::Flagged )
-        mailDirFlags << QLatin1String("F");
+        mailDirFlags << QLatin1String( "F" );
     }
     mailDirFlags.sort();
-    if (!mailDirFlags.isEmpty()) {
+    if ( !mailDirFlags.isEmpty() ) {
 #ifdef Q_OS_WIN
-      finalKey.append( QLatin1String("!2,") + mailDirFlags.join(QString()) );
+      finalKey.append( QLatin1String( "!2," ) + mailDirFlags.join( QString() ) );
 #else
-      finalKey.append( QLatin1String(":2,") + mailDirFlags.join(QString()) );
+      finalKey.append( QLatin1String( ":2," ) + mailDirFlags.join( QString() ) );
 #endif
     }
 
     QString newUniqueKey = finalKey; //key without path
-    finalKey.prepend( d->path + QString::fromLatin1("/cur/") );
+    finalKey.prepend( d->path + QString::fromLatin1( "/cur/" ) );
 
-    if( realKey == finalKey ) {
+    if ( realKey == finalKey ) {
       // Somehow it already is named this way (e.g. migration bug -> wrong status in akonadi)
       return newUniqueKey;
     }
 
     QFile f( realKey );
-    if (QFile::exists(finalKey)) {
-      QFile destFile(finalKey);
+    if ( QFile::exists( finalKey ) ) {
+      QFile destFile( finalKey );
       QByteArray destContent;
-      if (destFile.open(QIODevice::ReadOnly) ) {
+      if ( destFile.open( QIODevice::ReadOnly ) ) {
         destContent = destFile.readAll();
         destFile.close();
       }
       QByteArray sourceContent;
-      if (f.open(QIODevice::ReadOnly) ) {
+      if ( f.open( QIODevice::ReadOnly ) ) {
         sourceContent = f.readAll();
         f.close();
       }
@@ -662,20 +657,20 @@ QString Maildir::changeEntryFlags(const QString& key, const Akonadi::Item::Flags
       if ( destContent != sourceContent ) {
          QString newFinalKey = "1-" + newUniqueKey;
          int i = 1;
-         while ( QFile::exists(d->path + QString::fromLatin1("/cur/") + newFinalKey ) ) {
+         while ( QFile::exists( d->path + QString::fromLatin1( "/cur/" ) + newFinalKey ) ) {
            i++;
-           newFinalKey = QString::number(i) + "-" + newUniqueKey;
+           newFinalKey = QString::number( i ) + "-" + newUniqueKey;
          }
-         finalKey = d->path + QString::fromLatin1("/cur/") + newFinalKey;
+         finalKey = d->path + QString::fromLatin1( "/cur/" ) + newFinalKey;
       } else {
             QFile::remove( finalKey ); //they are the same
       }
     }
 
-    if (!f.rename( finalKey )) {
+    if ( !f.rename( finalKey ) ) {
         qWarning() << "Maildir: Failed to rename entry: " << f.fileName() << " to "  << finalKey  << "! Error: " << f.errorString();
         return QString();
-    }
+     }
 
     KeyCache *keyCache = KeyCache::self();
     keyCache->removeKey( d->path, key );
@@ -688,18 +683,18 @@ Akonadi::Item::Flags Maildir::readEntryFlags(const QString& key) const
 {
     Akonadi::Item::Flags flags;
 
-    const QRegExp rx = *(statusSeparatorRx());
+    const QRegExp rx = *( statusSeparatorRx() );
     const int index = key.indexOf( rx );
     if ( index != -1 ) {
         const QString mailDirFlags = key.mid( index + 3 ); // after "(:|!)2,"
         for ( int i = 0; i < mailDirFlags.size(); i++ ) {
-            if ( mailDirFlags[i] == QLatin1Char('P') )
+            if ( mailDirFlags[i] == QLatin1Char( 'P' ) )
                 flags << Akonadi::MessageFlags::Forwarded;
-            else if ( mailDirFlags[i] == QLatin1Char('R') )
+            else if ( mailDirFlags[i] == QLatin1Char( 'R' ) )
                 flags << Akonadi::MessageFlags::Replied;
-            else if ( mailDirFlags[i] == QLatin1Char('S') )
+            else if ( mailDirFlags[i] == QLatin1Char( 'S' ) )
                 flags << Akonadi::MessageFlags::Seen;
-            else if ( mailDirFlags[i] == QLatin1Char('F') )
+            else if ( mailDirFlags[i] == QLatin1Char( 'F' ) )
                 flags << Akonadi::MessageFlags::Flagged;
         }
     }
@@ -782,7 +777,7 @@ QString Maildir::subDirNameForFolderName( const QString &folderName )
 void Maildir::removeCachedKeys(const QStringList & keys)
 {
   KeyCache *keyCache = KeyCache::self();
-  foreach( const QString& key, keys ) {
+  Q_FOREACH ( const QString &key, keys ) {
     keyCache->removeKey( d->path, key );
   }
 }
